@@ -1,6 +1,6 @@
 use console_engine::pixel;
 use console_engine::screen::Screen;
-use console_engine::termion::color;
+use console_engine::Color;
 
 fn main() {
     // create a screen of 21x12 characters
@@ -10,7 +10,7 @@ fn main() {
 
     // create a new Screen struct and draw a square inside it
     let mut my_square = Screen::new(8, 8);
-    my_square.rect(0, 0, 7, 7, pixel::pxl_fg('#', color::LightBlue));
+    my_square.rect(0, 0, 7, 7, pixel::pxl_fg('#', Color::Blue));
     my_square.print(1, 1, "square");
 
     // prints the square in the main window at a specific location
@@ -18,5 +18,5 @@ fn main() {
     screen.print_screen(11, 2, &my_square);
 
     // print the main screen on the terminal
-    println!("{}", screen.to_string());
+    screen.draw();
 }
